@@ -722,9 +722,21 @@ class VariableClUpdateProfileStorage(ReadonlyVariable):
     type = "object"
 
     def get(self):
+        git = self.Get('cl_update_git')
         return RepositoryStorageSet(
-            LocalStorage('/var/lib/layman'),
-            CacheStorage('/var/calculate/tmp/update'))
+            LocalStorage(git, '/var/lib/layman'),
+            CacheStorage(git, '/var/calculate/tmp/update'))
+
+
+class VariableClUpdateGit(ReadonlyVariable):
+    type = "object"
+
+    def get(self):
+        sshkey = self.Get('update.cl_update_sshkey_path')
+        if path.exists(sshkey):
+            return Git(sshkey)
+        else:
+            return Git()
 
 
 class VariableClUpdateRepHost(Variable):
@@ -955,19 +967,16 @@ class VariableClUpdateProfileUrl(Variable):
         self.help = _("set the profile repository")
 
     re_url = re.compile(
-        r"^(?:(%s)://)?(\w[\w\./:-]+?\w)(\.git)?$" % "|".join(
-            ["http", "https", "git"]))
+        r"^(?:(%s)://)?((?:git@)?\w[\w\./:-]+?\w)(\.git)?$" % "|".join(
+            ["http", "https", "git", "ssh"]))
 
     re_shortname = re.compile('^(?:([\w\.-]+):)?([\w\.-]+)$')
 
     @classmethod
     def normalize_url(cls, url):
-        match = cls.re_url.match(url)
-        if not match:
+        url = Git.normalize_url(url)
+        if not url:
             raise VariableError(_("Wrong repository URL"))
-        url = match.group(2)
-        url = "%s://%s" % (match.group(1) or "git", url)
-        url = "%s.git" % url
         return url
 
     def url_by_shortname(self, value):
@@ -1024,8 +1033,7 @@ class VariableClUpdateProfileUrl(Variable):
                         raise CriticalError(
                             _("You need to update the repositories before "
                               "you change the profile"))
-                git = Git()
-                return git.get_url(profile, "origin") or self.default_url
+                return Git.get_url(profile, "origin") or self.default_url
         except CriticalError as e:
             raise VariableError(str(e))
         except Exception as e:
@@ -1088,13 +1096,14 @@ class VariableClProfileRepository(ReadonlyVariable):
 
     def get(self):
         try:
+            git = self.Get('cl_update_git')
             profile_dn = self.Get('cl_profile_system')
             while profile_dn != '/' and ".git" not in listDirectory(profile_dn):
                 profile_dn = path.dirname(profile_dn)
             if profile_dn == '/':
                 return ""
-            ls = LocalStorage(path.dirname(profile_dn))
-            return ProfileRepository(path.basename(profile_dn), ls)
+            ls = LocalStorage(git, path.dirname(profile_dn))
+            return ProfileRepository(git, path.basename(profile_dn), ls)
         except Exception:
             return ""
 
@@ -1785,3 +1794,9 @@ class VariableClUpdateUsetagSet(Variable):
     """
     type = Variable.Types.Boolean
     value = Variable.On
+
+class VariableClUpdateSshkeyPath(Variable):
+    """
+    Путь до ssh ключа
+    """
+    value = "/var/lib/calculate/id_rsa"
